.. _Part2:

---------------------
Part II - Development
---------------------

This part is about developing web applications with the *CubicWeb* framework.

.. toctree::
   :maxdepth: 2

   cubes/index
   datamodel/index
   entityclasses/index
   devcore/index
   devweb/index
   devrepo/index
   testing/index
   migration/index
   webstdlib/index
   profiling/index
